package
module
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Oct 1, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
README
¶
Documentation
¶
Properties returns the struct fields names list. obj can whether
be a structure or pointer to structure.
func PropertiesAsMap(obj interface{}) (map[string]interface{}, error)
PropertiesAsMap returns the properties of an item as a map
func Property(obj interface{}, fieldName string) (interface{}, error)
Property returns the specific property of obj
Tags lists the struct tag fields. obj can whether
be a structure or pointer to structure.
type KeyValue struct {
Key string
Value interface{}
}
KeyValue abstracts key with a value
String returns the key value pair in the form <key>=<value>
Source Files
¶
Click to show internal directories.
Click to hide internal directories.